/*******************************************************************************
 * Copyright (c) 2006 IBM Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - Jeff Briggs, Henry Hughes, Ryan Morse
 *******************************************************************************/

package org.eclipse.linuxtools.systemtap.ui.consolelog.preferences;

public interface ConsoleLogPreferenceConstants {
    String HOST_NAME = "host"; //$NON-NLS-1$
    String PORT_NUMBER = "port"; //$NON-NLS-1$
    String SCP_USER = "scpuser"; //$NON-NLS-1$
    String SCP_PASSWORD = "scppassword"; //$NON-NLS-1$
}
